/*******************************************************************************
 * Copyright (c) 2013, Perforce Software
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/
package com.perforce.p4java.extension.server.internal;

import com.perforce.p4java.extension.server.ServerLocation;
import com.perforce.p4java.extension.utility.Validate;

/**
 * 
 */
public class ServerLocationImpl implements ServerLocation {

    public static final String P4JAVA_URI_FORMATTER = "%s://%s:%d";
    private final String host;
    private final int port;
    private final String charset;
    private P4DProtocol protocol;

    public ServerLocationImpl(P4DProtocol protocol, String host, int port,
	    String charset) {
	Validate.greaterThanZero(port,
		"port must be greater than zero to ServerUri");
	Validate.notNull(host, "host must not be null to ServerUri");
	Validate.notNull(protocol, "protocol must not be null to ServerUri");
	this.host = host;
	this.port = port;
	this.protocol = protocol;
	this.charset = charset;
    }

    /**
     * @see com.perforce.p4java.extension.server.ServerLocation#toP4JavaUri()
     */
    public String toP4JavaUri() {
	return String.format(P4JAVA_URI_FORMATTER, protocol.toString(), host,
		port);
    }

    @Override
    public String toString() {
	return toP4JavaUri();
    }

    /**
     * @see com.perforce.p4java.extension.server.ServerLocation#getHost()
     */
    public String getHost() {
	return host;
    }

    /**
     * @see com.perforce.p4java.extension.server.ServerLocation#getPort()
     */
    public int getPort() {
	return port;
    }

    /**
     * @see com.perforce.p4java.extension.server.ServerLocation#getCharset()
     */
    public String getCharset() {
	return charset;
    }

    public P4DProtocol getProtocol() {
	return protocol;
    }

}
